@@ -1,13 +1,13 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 #
 # __init__.py
 #
-# Copyright (C) 2013 -  Wei-Ning Huang (AZ) <aitjcize@gmail.com>
+# Copyright (C) 2010 - 2014  Wei-Ning Huang (AZ) <aitjcize@gmail.com>
 # All Rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -24,5 +24,6 @@ import os
 
 package_dir = os.path.dirname(__file__)
 
+
 def get_lib_path(filename):
-    return os.path.join(package_dir, filename)
+    return os.path.join(package_dir, 'lib', filename)
